/*
  Java gfx-test framework

   Copyright (C) 2013, 2014  Red Hat

This file is part of IcedTea.

IcedTea is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

IcedTea is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with IcedTea; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
02110-1301 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version.
*/

package org.gfxtest.testsuites;

import java.awt.Graphics2D;
import java.awt.RenderingHints;
import java.awt.geom.AffineTransform;
import java.awt.image.AffineTransformOp;



import org.gfxtest.framework.TestImage;
import org.gfxtest.framework.TestResult;
import org.gfxtest.framework.annotations.BitBltOperation;
import org.gfxtest.framework.annotations.BitBltOperations;
import org.gfxtest.framework.annotations.GraphicsPrimitive;
import org.gfxtest.framework.annotations.GraphicsPrimitives;
import org.gfxtest.framework.annotations.RenderStyle;
import org.gfxtest.framework.annotations.RenderStyles;
import org.gfxtest.framework.annotations.TestType;
import org.gfxtest.framework.annotations.TestTypes;
import org.gfxtest.framework.annotations.Transformation;
import org.gfxtest.framework.annotations.Transformations;
import org.gfxtest.framework.annotations.Zoom;



@TestType(TestTypes.RENDER_TEST)
@GraphicsPrimitive(GraphicsPrimitives.COMMON_BITMAP)
@RenderStyle(RenderStyles.NORMAL)
@BitBltOperation(BitBltOperations.BITBLT)
@Transformation(Transformations.ROTATION)
@Zoom(1)
public class BitBltAffineQuadrantRotateTransformOp extends BitBltAffineTransformOp
{
    private static final int NUM_ROTATIONS = 6;

    private static final AffineTransform RotateTransformation[] = new AffineTransform[NUM_ROTATIONS];

    private static final RenderingHints RenderingHintsNearestNeighbor;
    private static final RenderingHints RenderingHintsBilinear;
    private static final RenderingHints RenderingHintsBicubic;

    private static AffineTransformOp RotateTransformationNearest1Op[] = new AffineTransformOp[NUM_ROTATIONS];
    private static AffineTransformOp RotateTransformationBilinear1Op[] = new AffineTransformOp[NUM_ROTATIONS];
    private static AffineTransformOp RotateTransformationBicubic1Op[] = new AffineTransformOp[NUM_ROTATIONS];

    private static AffineTransformOp RotateTransformationNearest2Op[] = new AffineTransformOp[NUM_ROTATIONS];
    private static AffineTransformOp RotateTransformationBilinear2Op[] = new AffineTransformOp[NUM_ROTATIONS];
    private static AffineTransformOp RotateTransformationBicubic2Op[] = new AffineTransformOp[NUM_ROTATIONS];

    static
    {
        RenderingHintsNearestNeighbor = new RenderingHints(RenderingHints.KEY_INTERPOLATION, RenderingHints.VALUE_INTERPOLATION_NEAREST_NEIGHBOR);
        RenderingHintsBilinear = new RenderingHints(RenderingHints.KEY_INTERPOLATION, RenderingHints.VALUE_INTERPOLATION_BILINEAR);
        RenderingHintsBicubic = new RenderingHints(RenderingHints.KEY_INTERPOLATION, RenderingHints.VALUE_INTERPOLATION_BICUBIC);

        for (int i = 0; i < NUM_ROTATIONS; i++)
        {
            RotateTransformation[i] = AffineTransform.getQuadrantRotateInstance(i);
            
            RotateTransformationNearest1Op[i] = new AffineTransformOp(RotateTransformation[i], AffineTransformOp.TYPE_NEAREST_NEIGHBOR);
            RotateTransformationBilinear1Op[i] = new AffineTransformOp(RotateTransformation[i], AffineTransformOp.TYPE_BILINEAR);
            RotateTransformationBicubic1Op[i] = new AffineTransformOp(RotateTransformation[i], AffineTransformOp.TYPE_BICUBIC);

            RotateTransformationNearest2Op[i] = new AffineTransformOp(RotateTransformation[i], RenderingHintsNearestNeighbor);
            RotateTransformationBilinear2Op[i] = new AffineTransformOp(RotateTransformation[i], RenderingHintsBilinear);
            RotateTransformationBicubic2Op[i] = new AffineTransformOp(RotateTransformation[i], RenderingHintsBicubic);
        }

    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_3BYTE_BGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageType3ByteBGRRotateTransformation0Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageType3ByteRGB(image, graphics2d, RotateTransformationNearest1Op[0]);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_3BYTE_BGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageType3ByteBGRRotateTransformation1Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageType3ByteRGB(image, graphics2d, RotateTransformationNearest1Op[1]);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_3BYTE_BGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageType3ByteBGRRotateTransformation2Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageType3ByteRGB(image, graphics2d, RotateTransformationNearest1Op[2]);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_3BYTE_BGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageType3ByteBGRRotateTransformation3Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageType3ByteRGB(image, graphics2d, RotateTransformationNearest1Op[3]);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_3BYTE_BGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageType3ByteBGRRotateTransformation4Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageType3ByteRGB(image, graphics2d, RotateTransformationNearest1Op[4]);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_3BYTE_BGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageType3ByteBGRRotateTransformation5Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageType3ByteRGB(image, graphics2d, RotateTransformationNearest1Op[5]);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_4BYTE_ABGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageType4ByteABGRRotateTransformation0Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageType4ByteABGR(image, graphics2d, RotateTransformationNearest1Op[0]);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_4BYTE_ABGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageType4ByteABGRRotateTransformation1Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageType4ByteABGR(image, graphics2d, RotateTransformationNearest1Op[1]);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_4BYTE_ABGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageType4ByteABGRRotateTransformation2Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageType4ByteABGR(image, graphics2d, RotateTransformationNearest1Op[2]);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_4BYTE_ABGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageType4ByteABGRRotateTransformation3Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageType4ByteABGR(image, graphics2d, RotateTransformationNearest1Op[3]);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_4BYTE_ABGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageType4ByteABGRRotateTransformation4Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageType4ByteABGR(image, graphics2d, RotateTransformationNearest1Op[4]);
    }

    /**
      Test basic BitBlt operation for empty buffered image with type TYPE_4BYTE_ABGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageType4ByteABGRRotateTransformation5Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageType4ByteABGR(image, graphics2d, RotateTransformationNearest1Op[5]);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_4BYTE_ABGR_PRE.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageType4ByteABGRPreRotateTransformation0Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageType4ByteABGRPre(image, graphics2d, RotateTransformationNearest1Op[0]);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_4BYTE_ABGR_PRE.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageType4ByteABGRPreRotateTransformation1Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageType4ByteABGRPre(image, graphics2d, RotateTransformationNearest1Op[1]);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_4BYTE_ABGR_PRE.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageType4ByteABGRPreRotateTransformation2Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageType4ByteABGRPre(image, graphics2d, RotateTransformationNearest1Op[2]);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_4BYTE_ABGR_PRE.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageType4ByteABGRPreRotateTransformation3Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageType4ByteABGRPre(image, graphics2d, RotateTransformationNearest1Op[3]);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_4BYTE_ABGR_PRE.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageType4ByteABGRPreRotateTransformation4Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageType4ByteABGRPre(image, graphics2d, RotateTransformationNearest1Op[4]);
    }

    /**
      Test basic BitBlt operation for empty buffered image with type TYPE_4BYTE_ABGR_PRE.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageType4ByteABGRPreRotateTransformation5Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageType4ByteABGRPre(image, graphics2d, RotateTransformationNearest1Op[5]);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_BYTE_BINARY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeByteBinaryRotateTransformation0Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeByteBinary(image, graphics2d, RotateTransformationNearest1Op[0]);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_BYTE_BINARY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeByteBinaryRotateTransformation1Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeByteBinary(image, graphics2d, RotateTransformationNearest1Op[1]);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_BYTE_BINARY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeByteBinaryRotateTransformation2Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeByteBinary(image, graphics2d, RotateTransformationNearest1Op[2]);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_BYTE_BINARY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeByteBinaryRotateTransformation3Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeByteBinary(image, graphics2d, RotateTransformationNearest1Op[3]);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_BYTE_BINARY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeByteBinaryRotateTransformation4Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeByteBinary(image, graphics2d, RotateTransformationNearest1Op[4]);
    }

    /**
      Test basic BitBlt operation for empty buffered image with type TYPE_BYTE_BINARY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeByteBinaryRotateTransformation5Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeByteBinary(image, graphics2d, RotateTransformationNearest1Op[5]);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_BYTE_INDEXED.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeByteIndexedRotateTransformation0Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeByteIndexed(image, graphics2d, RotateTransformationNearest1Op[0]);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_BYTE_INDEXED.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeByteIndexedRotateTransformation1Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeByteIndexed(image, graphics2d, RotateTransformationNearest1Op[1]);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_BYTE_INDEXED.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeByteIndexedRotateTransformation2Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeByteIndexed(image, graphics2d, RotateTransformationNearest1Op[2]);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_BYTE_INDEXED.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeByteIndexedRotateTransformation3Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeByteIndexed(image, graphics2d, RotateTransformationNearest1Op[3]);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_BYTE_INDEXED.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeByteIndexedRotateTransformation4Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeByteIndexed(image, graphics2d, RotateTransformationNearest1Op[4]);
    }

    /**
      Test basic BitBlt operation for empty buffered image with type TYPE_BYTE_INDEXED.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeByteIndexedRotateTransformation5Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeByteIndexed(image, graphics2d, RotateTransformationNearest1Op[5]);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_BYTE_GRAY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeByteGrayRotateTransformation0Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeByteGray(image, graphics2d, RotateTransformationNearest1Op[0]);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_BYTE_GRAY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeByteGrayRotateTransformation1Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeByteGray(image, graphics2d, RotateTransformationNearest1Op[1]);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_BYTE_GRAY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeByteGrayRotateTransformation2Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeByteGray(image, graphics2d, RotateTransformationNearest1Op[2]);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_BYTE_GRAY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeByteGrayRotateTransformation3Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeByteGray(image, graphics2d, RotateTransformationNearest1Op[3]);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_BYTE_GRAY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeByteGrayRotateTransformation4Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeByteGray(image, graphics2d, RotateTransformationNearest1Op[4]);
    }

    /**
      Test basic BitBlt operation for empty buffered image with type TYPE_BYTE_GRAY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeByteGrayRotateTransformation5Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeByteGray(image, graphics2d, RotateTransformationNearest1Op[5]);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_CUSTOM.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeCustomRotateTransformation0Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeCustom(image, graphics2d, RotateTransformationNearest1Op[0]);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_CUSTOM.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeCustomRotateTransformation1Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeCustom(image, graphics2d, RotateTransformationNearest1Op[1]);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_CUSTOM.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeCustomRotateTransformation2Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeCustom(image, graphics2d, RotateTransformationNearest1Op[2]);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_CUSTOM.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeCustomRotateTransformation3Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeCustom(image, graphics2d, RotateTransformationNearest1Op[3]);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_CUSTOM.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeCustomRotateTransformation4Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeCustom(image, graphics2d, RotateTransformationNearest1Op[4]);
    }

    /**
      Test basic BitBlt operation for empty buffered image with type TYPE_CUSTOM.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeCustomRotateTransformation5Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeCustom(image, graphics2d, RotateTransformationNearest1Op[5]);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_INT_ARGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeIntARGBRotateTransformation0Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeIntARGB(image, graphics2d, RotateTransformationNearest1Op[0]);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_INT_ARGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeIntARGBRotateTransformation1Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeIntARGB(image, graphics2d, RotateTransformationNearest1Op[1]);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_INT_ARGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeIntARGBRotateTransformation2Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeIntARGB(image, graphics2d, RotateTransformationNearest1Op[2]);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_INT_ARGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeIntARGBRotateTransformation3Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeIntARGB(image, graphics2d, RotateTransformationNearest1Op[3]);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_INT_ARGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeIntARGBRotateTransformation4Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeIntARGB(image, graphics2d, RotateTransformationNearest1Op[4]);
    }

    /**
      Test basic BitBlt operation for empty buffered image with type TYPE_INT_ARGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeIntARGBRotateTransformation5Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeIntARGB(image, graphics2d, RotateTransformationNearest1Op[5]);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_INT_ARGB_PRE.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeIntARGBPreRotateTransformation0Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeIntARGBPre(image, graphics2d, RotateTransformationNearest1Op[0]);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_INT_ARGB_PRE.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeIntARGBPreRotateTransformation1Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeIntARGBPre(image, graphics2d, RotateTransformationNearest1Op[1]);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_INT_ARGB_PRE.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeIntARGBPreRotateTransformation2Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeIntARGBPre(image, graphics2d, RotateTransformationNearest1Op[2]);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_INT_ARGB_PRE.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeIntARGBPreRotateTransformation3Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeIntARGBPre(image, graphics2d, RotateTransformationNearest1Op[3]);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_INT_ARGB_PRE.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeIntARGBPreRotateTransformation4Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeIntARGBPre(image, graphics2d, RotateTransformationNearest1Op[4]);
    }

    /**
      Test basic BitBlt operation for empty buffered image with type TYPE_INT_ARGB_PRE.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeIntARGBPreRotateTransformation5Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeIntARGBPre(image, graphics2d, RotateTransformationNearest1Op[5]);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_INT_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeIntRGBRotateTransformation0Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeIntRGB(image, graphics2d, RotateTransformationNearest1Op[0]);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_INT_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeIntRGBRotateTransformation1Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeIntRGB(image, graphics2d, RotateTransformationNearest1Op[1]);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_INT_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeIntRGBRotateTransformation2Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeIntRGB(image, graphics2d, RotateTransformationNearest1Op[2]);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_INT_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeIntRGBRotateTransformation3Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeIntRGB(image, graphics2d, RotateTransformationNearest1Op[3]);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_INT_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeIntRGBRotateTransformation4Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeIntRGB(image, graphics2d, RotateTransformationNearest1Op[4]);
    }

    /**
      Test basic BitBlt operation for empty buffered image with type TYPE_INT_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeIntRGBRotateTransformation5Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeIntRGB(image, graphics2d, RotateTransformationNearest1Op[5]);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_INT_BGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeIntBGRRotateTransformation0Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeIntBGR(image, graphics2d, RotateTransformationNearest1Op[0]);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_INT_BGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeIntBGRRotateTransformation1Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeIntBGR(image, graphics2d, RotateTransformationNearest1Op[1]);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_INT_BGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeIntBGRRotateTransformation2Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeIntBGR(image, graphics2d, RotateTransformationNearest1Op[2]);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_INT_BGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeIntBGRRotateTransformation3Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeIntBGR(image, graphics2d, RotateTransformationNearest1Op[3]);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_INT_BGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeIntBGRRotateTransformation4Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeIntBGR(image, graphics2d, RotateTransformationNearest1Op[4]);
    }

    /**
      Test basic BitBlt operation for empty buffered image with type TYPE_INT_BGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeIntBGRRotateTransformation5Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeIntBGR(image, graphics2d, RotateTransformationNearest1Op[5]);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_USHORT_555_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeUshort555RGBRotateTransformation0Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeUshort555RGB(image, graphics2d, RotateTransformationNearest1Op[0]);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_USHORT_555_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeUshort555RGBRotateTransformation1Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeUshort555RGB(image, graphics2d, RotateTransformationNearest1Op[1]);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_USHORT_555_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeUshort555RGBRotateTransformation2Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeUshort555RGB(image, graphics2d, RotateTransformationNearest1Op[2]);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_USHORT_555_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeUshort555RGBRotateTransformation3Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeUshort555RGB(image, graphics2d, RotateTransformationNearest1Op[3]);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_USHORT_555_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeUshort555RGBRotateTransformation4Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeUshort555RGB(image, graphics2d, RotateTransformationNearest1Op[4]);
    }

    /**
      Test basic BitBlt operation for empty buffered image with type TYPE_USHORT_555_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeUshort555RGBRotateTransformation5Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeUshort555RGB(image, graphics2d, RotateTransformationNearest1Op[5]);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_USHORT_565_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeUshort565RGBRotateTransformation0Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeUshort565RGB(image, graphics2d, RotateTransformationNearest1Op[0]);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_USHORT_565_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeUshort565RGBRotateTransformation1Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeUshort565RGB(image, graphics2d, RotateTransformationNearest1Op[1]);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_USHORT_565_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeUshort565RGBRotateTransformation2Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeUshort565RGB(image, graphics2d, RotateTransformationNearest1Op[2]);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_USHORT_565_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeUshort565RGBRotateTransformation3Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeUshort565RGB(image, graphics2d, RotateTransformationNearest1Op[3]);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_USHORT_565_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeUshort565RGBRotateTransformation4Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeUshort565RGB(image, graphics2d, RotateTransformationNearest1Op[4]);
    }

    /**
      Test basic BitBlt operation for empty buffered image with type TYPE_USHORT_565_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeUshort565RGBRotateTransformation5Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeUshort565RGB(image, graphics2d, RotateTransformationNearest1Op[5]);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_USHORT_GRAY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeUshortGrayRotateTransformation0Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeUshortGray(image, graphics2d, RotateTransformationNearest1Op[0]);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_USHORT_GRAY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeUshortGrayRotateTransformation1Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeUshortGray(image, graphics2d, RotateTransformationNearest1Op[1]);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_USHORT_GRAY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeUshortGrayRotateTransformation2Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeUshortGray(image, graphics2d, RotateTransformationNearest1Op[2]);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_USHORT_GRAY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeUshortGrayRotateTransformation3Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeUshortGray(image, graphics2d, RotateTransformationNearest1Op[3]);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_USHORT_GRAY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeUshortGrayRotateTransformation4Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeUshortGray(image, graphics2d, RotateTransformationNearest1Op[4]);
    }

    /**
      Test basic BitBlt operation for empty buffered image with type TYPE_USHORT_GRAY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeUshortGrayRotateTransformation5Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeUshortGray(image, graphics2d, RotateTransformationNearest1Op[5]);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_3BYTE_BGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageType3ByteBGRRotateTransformation0Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageType3ByteRGB(image, graphics2d, RotateTransformationNearest1Op[0]);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_3BYTE_BGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageType3ByteBGRRotateTransformation1Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageType3ByteRGB(image, graphics2d, RotateTransformationNearest1Op[1]);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_3BYTE_BGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageType3ByteBGRRotateTransformation2Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageType3ByteRGB(image, graphics2d, RotateTransformationNearest1Op[2]);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_3BYTE_BGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageType3ByteBGRRotateTransformation3Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageType3ByteRGB(image, graphics2d, RotateTransformationNearest1Op[3]);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_3BYTE_BGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageType3ByteBGRRotateTransformation4Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageType3ByteRGB(image, graphics2d, RotateTransformationNearest1Op[4]);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_3BYTE_BGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageType3ByteBGRRotateTransformation5Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageType3ByteRGB(image, graphics2d, RotateTransformationNearest1Op[5]);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_4BYTE_ABGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageType4ByteABGRRotateTransformation0Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageType4ByteABGR(image, graphics2d, RotateTransformationNearest1Op[0]);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_4BYTE_ABGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageType4ByteABGRRotateTransformation1Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageType4ByteABGR(image, graphics2d, RotateTransformationNearest1Op[1]);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_4BYTE_ABGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageType4ByteABGRRotateTransformation2Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageType4ByteABGR(image, graphics2d, RotateTransformationNearest1Op[2]);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_4BYTE_ABGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageType4ByteABGRRotateTransformation3Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageType4ByteABGR(image, graphics2d, RotateTransformationNearest1Op[3]);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_4BYTE_ABGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageType4ByteABGRRotateTransformation4Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageType4ByteABGR(image, graphics2d, RotateTransformationNearest1Op[4]);
    }

    /**
      Test basic BitBlt operation for checker buffered image with type TYPE_4BYTE_ABGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageType4ByteABGRRotateTransformation5Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageType4ByteABGR(image, graphics2d, RotateTransformationNearest1Op[5]);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_4BYTE_ABGR_PRE.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageType4ByteABGRPreRotateTransformation0Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageType4ByteABGRPre(image, graphics2d, RotateTransformationNearest1Op[0]);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_4BYTE_ABGR_PRE.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageType4ByteABGRPreRotateTransformation1Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageType4ByteABGRPre(image, graphics2d, RotateTransformationNearest1Op[1]);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_4BYTE_ABGR_PRE.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageType4ByteABGRPreRotateTransformation2Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageType4ByteABGRPre(image, graphics2d, RotateTransformationNearest1Op[2]);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_4BYTE_ABGR_PRE.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageType4ByteABGRPreRotateTransformation3Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageType4ByteABGRPre(image, graphics2d, RotateTransformationNearest1Op[3]);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_4BYTE_ABGR_PRE.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageType4ByteABGRPreRotateTransformation4Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageType4ByteABGRPre(image, graphics2d, RotateTransformationNearest1Op[4]);
    }

    /**
      Test basic BitBlt operation for checker buffered image with type TYPE_4BYTE_ABGR_PRE.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageType4ByteABGRPreRotateTransformation5Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageType4ByteABGRPre(image, graphics2d, RotateTransformationNearest1Op[5]);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_BYTE_BINARY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeByteBinaryRotateTransformation0Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeByteBinary(image, graphics2d, RotateTransformationNearest1Op[0]);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_BYTE_BINARY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeByteBinaryRotateTransformation1Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeByteBinary(image, graphics2d, RotateTransformationNearest1Op[1]);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_BYTE_BINARY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeByteBinaryRotateTransformation2Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeByteBinary(image, graphics2d, RotateTransformationNearest1Op[2]);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_BYTE_BINARY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeByteBinaryRotateTransformation3Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeByteBinary(image, graphics2d, RotateTransformationNearest1Op[3]);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_BYTE_BINARY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeByteBinaryRotateTransformation4Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeByteBinary(image, graphics2d, RotateTransformationNearest1Op[4]);
    }

    /**
      Test basic BitBlt operation for checker buffered image with type TYPE_BYTE_BINARY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeByteBinaryRotateTransformation5Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeByteBinary(image, graphics2d, RotateTransformationNearest1Op[5]);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_BYTE_INDEXED.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeByteIndexedRotateTransformation0Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeByteIndexed(image, graphics2d, RotateTransformationNearest1Op[0]);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_BYTE_INDEXED.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeByteIndexedRotateTransformation1Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeByteIndexed(image, graphics2d, RotateTransformationNearest1Op[1]);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_BYTE_INDEXED.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeByteIndexedRotateTransformation2Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeByteIndexed(image, graphics2d, RotateTransformationNearest1Op[2]);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_BYTE_INDEXED.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeByteIndexedRotateTransformation3Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeByteIndexed(image, graphics2d, RotateTransformationNearest1Op[3]);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_BYTE_INDEXED.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeByteIndexedRotateTransformation4Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeByteIndexed(image, graphics2d, RotateTransformationNearest1Op[4]);
    }

    /**
      Test basic BitBlt operation for checker buffered image with type TYPE_BYTE_INDEXED.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeByteIndexedRotateTransformation5Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeByteIndexed(image, graphics2d, RotateTransformationNearest1Op[5]);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_BYTE_GRAY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeByteGrayRotateTransformation0Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeByteGray(image, graphics2d, RotateTransformationNearest1Op[0]);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_BYTE_GRAY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeByteGrayRotateTransformation1Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeByteGray(image, graphics2d, RotateTransformationNearest1Op[1]);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_BYTE_GRAY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeByteGrayRotateTransformation2Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeByteGray(image, graphics2d, RotateTransformationNearest1Op[2]);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_BYTE_GRAY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeByteGrayRotateTransformation3Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeByteGray(image, graphics2d, RotateTransformationNearest1Op[3]);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_BYTE_GRAY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeByteGrayRotateTransformation4Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeByteGray(image, graphics2d, RotateTransformationNearest1Op[4]);
    }

    /**
      Test basic BitBlt operation for checker buffered image with type TYPE_BYTE_GRAY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeByteGrayRotateTransformation5Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeByteGray(image, graphics2d, RotateTransformationNearest1Op[5]);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_CUSTOM.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeCustomRotateTransformation0Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeCustom(image, graphics2d, RotateTransformationNearest1Op[0]);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_CUSTOM.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeCustomRotateTransformation1Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeCustom(image, graphics2d, RotateTransformationNearest1Op[1]);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_CUSTOM.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeCustomRotateTransformation2Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeCustom(image, graphics2d, RotateTransformationNearest1Op[2]);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_CUSTOM.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeCustomRotateTransformation3Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeCustom(image, graphics2d, RotateTransformationNearest1Op[3]);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_CUSTOM.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeCustomRotateTransformation4Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeCustom(image, graphics2d, RotateTransformationNearest1Op[4]);
    }

    /**
      Test basic BitBlt operation for checker buffered image with type TYPE_CUSTOM.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeCustomRotateTransformation5Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeCustom(image, graphics2d, RotateTransformationNearest1Op[5]);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_INT_ARGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeIntARGBRotateTransformation0Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeIntARGB(image, graphics2d, RotateTransformationNearest1Op[0]);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_INT_ARGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeIntARGBRotateTransformation1Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeIntARGB(image, graphics2d, RotateTransformationNearest1Op[1]);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_INT_ARGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeIntARGBRotateTransformation2Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeIntARGB(image, graphics2d, RotateTransformationNearest1Op[2]);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_INT_ARGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeIntARGBRotateTransformation3Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeIntARGB(image, graphics2d, RotateTransformationNearest1Op[3]);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_INT_ARGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeIntARGBRotateTransformation4Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeIntARGB(image, graphics2d, RotateTransformationNearest1Op[4]);
    }

    /**
      Test basic BitBlt operation for checker buffered image with type TYPE_INT_ARGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeIntARGBRotateTransformation5Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeIntARGB(image, graphics2d, RotateTransformationNearest1Op[5]);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_INT_ARGB_PRE.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeIntARGBPreRotateTransformation0Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeIntARGBPre(image, graphics2d, RotateTransformationNearest1Op[0]);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_INT_ARGB_PRE.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeIntARGBPreRotateTransformation1Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeIntARGBPre(image, graphics2d, RotateTransformationNearest1Op[1]);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_INT_ARGB_PRE.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeIntARGBPreRotateTransformation2Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeIntARGBPre(image, graphics2d, RotateTransformationNearest1Op[2]);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_INT_ARGB_PRE.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeIntARGBPreRotateTransformation3Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeIntARGBPre(image, graphics2d, RotateTransformationNearest1Op[3]);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_INT_ARGB_PRE.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeIntARGBPreRotateTransformation4Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeIntARGBPre(image, graphics2d, RotateTransformationNearest1Op[4]);
    }

    /**
      Test basic BitBlt operation for checker buffered image with type TYPE_INT_ARGB_PRE.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeIntARGBPreRotateTransformation5Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeIntARGBPre(image, graphics2d, RotateTransformationNearest1Op[5]);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_INT_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeIntRGBRotateTransformation0Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeIntRGB(image, graphics2d, RotateTransformationNearest1Op[0]);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_INT_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeIntRGBRotateTransformation1Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeIntRGB(image, graphics2d, RotateTransformationNearest1Op[1]);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_INT_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeIntRGBRotateTransformation2Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeIntRGB(image, graphics2d, RotateTransformationNearest1Op[2]);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_INT_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeIntRGBRotateTransformation3Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeIntRGB(image, graphics2d, RotateTransformationNearest1Op[3]);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_INT_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeIntRGBRotateTransformation4Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeIntRGB(image, graphics2d, RotateTransformationNearest1Op[4]);
    }

    /**
      Test basic BitBlt operation for checker buffered image with type TYPE_INT_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeIntRGBRotateTransformation5Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeIntRGB(image, graphics2d, RotateTransformationNearest1Op[5]);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_INT_BGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeIntBGRRotateTransformation0Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeIntBGR(image, graphics2d, RotateTransformationNearest1Op[0]);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_INT_BGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeIntBGRRotateTransformation1Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeIntBGR(image, graphics2d, RotateTransformationNearest1Op[1]);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_INT_BGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeIntBGRRotateTransformation2Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeIntBGR(image, graphics2d, RotateTransformationNearest1Op[2]);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_INT_BGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeIntBGRRotateTransformation3Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeIntBGR(image, graphics2d, RotateTransformationNearest1Op[3]);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_INT_BGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeIntBGRRotateTransformation4Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeIntBGR(image, graphics2d, RotateTransformationNearest1Op[4]);
    }

    /**
      Test basic BitBlt operation for checker buffered image with type TYPE_INT_BGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeIntBGRRotateTransformation5Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeIntBGR(image, graphics2d, RotateTransformationNearest1Op[5]);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_USHORT_555_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeUshort555RGBRotateTransformation0Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeUshort555RGB(image, graphics2d, RotateTransformationNearest1Op[0]);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_USHORT_555_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeUshort555RGBRotateTransformation1Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeUshort555RGB(image, graphics2d, RotateTransformationNearest1Op[1]);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_USHORT_555_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeUshort555RGBRotateTransformation2Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeUshort555RGB(image, graphics2d, RotateTransformationNearest1Op[2]);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_USHORT_555_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeUshort555RGBRotateTransformation3Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeUshort555RGB(image, graphics2d, RotateTransformationNearest1Op[3]);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_USHORT_555_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeUshort555RGBRotateTransformation4Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeUshort555RGB(image, graphics2d, RotateTransformationNearest1Op[4]);
    }

    /**
      Test basic BitBlt operation for checker buffered image with type TYPE_USHORT_555_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeUshort555RGBRotateTransformation5Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeUshort555RGB(image, graphics2d, RotateTransformationNearest1Op[5]);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_USHORT_565_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeUshort565RGBRotateTransformation0Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeUshort565RGB(image, graphics2d, RotateTransformationNearest1Op[0]);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_USHORT_565_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeUshort565RGBRotateTransformation1Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeUshort565RGB(image, graphics2d, RotateTransformationNearest1Op[1]);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_USHORT_565_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeUshort565RGBRotateTransformation2Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeUshort565RGB(image, graphics2d, RotateTransformationNearest1Op[2]);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_USHORT_565_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeUshort565RGBRotateTransformation3Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeUshort565RGB(image, graphics2d, RotateTransformationNearest1Op[3]);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_USHORT_565_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeUshort565RGBRotateTransformation4Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeUshort565RGB(image, graphics2d, RotateTransformationNearest1Op[4]);
    }

    /**
      Test basic BitBlt operation for checker buffered image with type TYPE_USHORT_565_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeUshort565RGBRotateTransformation5Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeUshort565RGB(image, graphics2d, RotateTransformationNearest1Op[5]);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_USHORT_GRAY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeUshortGrayRotateTransformation0Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeUshortGray(image, graphics2d, RotateTransformationNearest1Op[0]);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_USHORT_GRAY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeUshortGrayRotateTransformation1Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeUshortGray(image, graphics2d, RotateTransformationNearest1Op[1]);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_USHORT_GRAY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeUshortGrayRotateTransformation2Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeUshortGray(image, graphics2d, RotateTransformationNearest1Op[2]);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_USHORT_GRAY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeUshortGrayRotateTransformation3Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeUshortGray(image, graphics2d, RotateTransformationNearest1Op[3]);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_USHORT_GRAY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeUshortGrayRotateTransformation4Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeUshortGray(image, graphics2d, RotateTransformationNearest1Op[4]);
    }

    /**
      Test basic BitBlt operation for checker buffered image with type TYPE_USHORT_GRAY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeUshortGrayRotateTransformation5Nearest1Op(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeUshortGray(image, graphics2d, RotateTransformationNearest1Op[5]);
    }

    /**
     * Entry point to the test suite.
     *
     * @param args not used in this case
     */
    public static void main(String[] args)
    {
        new BitBltAffineQuadrantRotateTransformOp().runTestSuite(args);
    }
    
}
